@@ -1020,7 +1020,7 @@ macro_rules! concat_g_impl {
     ) => {
         $crate::std_compile_error!($crate::std_concat!(
             "invalid generics '",
-            $crate::std_stringify!($($item:tt)*),
+            $crate::std_stringify!($($item)*),
             "'"
         ));
     };
@@ -1165,7 +1165,7 @@ macro_rules! concat_g_impl {
     ) => {
         $crate::std_compile_error!($crate::std_concat!(
             "invalid generics '",
-            $crate::std_stringify!($($tail:tt)+),
+            $crate::std_stringify!($($tail)+),
             "'"
         ));
     };
@@ -1400,7 +1400,7 @@ macro_rules! concat_r_impl {
     ) => {
         $crate::std_compile_error!($crate::std_concat!(
             "invalid generics '",
-            $crate::std_stringify!($($tail:tt)+),
+            $crate::std_stringify!($($tail)+),
             "'"
         ));
     };
@@ -1457,7 +1457,7 @@ macro_rules! concat_w_impl {
     ) => {
         $crate::std_compile_error!($crate::std_concat!(
             "invalid generics '",
-            $crate::std_stringify!($($item:tt)+),
+            $crate::std_stringify!($($item)+),
             "'"
         ));
     };
@@ -1664,4 +1664,36 @@ mod tests {
         let _ = x.c;
         let _ = x.d;
     }
+
+    macro_rules! descr {
+        (
+            impl $($token:tt)*
+        ) => {
+            parse! {
+                descr {
+                    @impl
+                }
+                $($token)*
+            }
+        };
+        (
+            @impl [$($g:tt)*] [$($r:tt)*] [$($w:tt)*] $t:ty { $($body:tt)* }
+        ) => {
+            impl $($g)* $t $($w)* { $($body)* }
+        };
+    }
+
+    struct Test<A>(A);
+
+    descr! {
+        impl<A> Test<A> where A: Clone {
+            fn a(&self) { }
+        }
+    }
+
+    #[test]
+    fn run_test() {
+        let x: Test<u32> = Test(7);
+        x.a();
+    }
 }
